@@ -78,6 +78,7 @@ class UserHandler():
             self.session.commit()
             return True
         except Exception as e:
+            self.session.rollback()
             raise Exception(e)
 
     def get_user_metadata(self, user_id: uuid = None, username: str = None) -> dict:
@@ -109,6 +110,8 @@ class UserHandler():
         else:
             user = self.session.query(User).filter((User.user_id == user_id) & (User.username == username) & (User.study_name == self.study_name)).first()
 
+        self.close()
+
         if user:
             return user.user_metadata
         else:
@@ -137,14 +140,19 @@ class UserHandler():
             raise ValueError("User ID or auth token cannot be empty.")
 
         if username and not auth_token:
-            user = self.session.query(User.user_settings).filter((User.username == username) & (User.study_name == self.study_name)).first()
+            user = self.session.query(User.user_settings, User.username, User.user_id).filter((User.username == username) & (User.study_name == self.study_name)).first()
         elif not username and auth_token:
-            user = self.session.query(User.user_settings).filter((User.token == auth_token) & (User.study_name == self.study_name)).first()
+            user = self.session.query(User.user_settings, User.username, User.user_id).filter((User.token == auth_token) & (User.study_name == self.study_name)).first()
         else:
-            user = self.session.query(User.user_settings).filter((User.username == username) & (User.token == auth_token) & (User.study_name == self.study_name)).first()
+            user = self.session.query(User.user_settings, User.username, User.user_id).filter((User.username == username) & (User.token == auth_token) & (User.study_name == self.study_name)).first()
+
+        self.close()
 
         if user:
-            return user.user_settings
+            user_info = user.user_settings
+            user_info["username"] = user.username
+            user_info["user_id"] = user.user_id
+            return user_info
         else:
             return {}
 
@@ -181,6 +189,8 @@ class UserHandler():
         token = jwt.encode({'username': username, "token_expire_at":str(token_expiry), "token_issued_at":str(token_issue_time)}, self.config["cc"]["auth_encryption_key"], algorithm='HS256')
         token = token.decode("utf-8")
 
+        self.close()
+
         if not user:
             return {"status":False, "auth_token": "", "msg":" Incorrect username and/or password."}
         elif not self.update_auth_token(username, token, token_issue_time, token_expiry):
@@ -207,6 +217,8 @@ class UserHandler():
         user = self.session.query(User).filter(
             (User.username == username) & (User.token == auth_token) & (User.study_name == self.study_name)).first()
 
+        self.close()
+
         if not user:
             return False
         elif not checktime:
@@ -239,6 +251,8 @@ class UserHandler():
 
         rows = self.session.query(User.user_id, User.username).filter(User.study_name == self.study_name).all()
 
+        self.close()
+
         if rows:
             return rows
         else:
@@ -264,6 +278,8 @@ class UserHandler():
 
         user = self.session.query(User.username).filter((User.user_id==user_id) & (User.study_name == self.study_name)).first()
 
+        self.close()
+
         if not user:
             raise Exception(str(user_id)+" does not exist.")
         else:
@@ -289,6 +305,8 @@ class UserHandler():
 
         user = self.session.query(User.user_id).filter((User.username==user_name) & (User.study_name == self.study_name)).first()
 
+        self.close()
+
         if not user:
             raise Exception(str(user_name)+ " does not exist.")
         else:
@@ -310,6 +328,7 @@ class UserHandler():
             >>> CC.is_user(user_id="76cc444c-4fb8-776e-2872-9472b4e66b16")
             >>> True
         """
+
         if user_id and user_name:
             user = self.session.query(User.username).filter(
                 (User.user_id == user_id) & (User.username==user_name) & (User.study_name == self.study_name)).first()
@@ -322,6 +341,8 @@ class UserHandler():
         else:
             raise ValueError("Both user_id and user_name cannot be None or empty.")
 
+        self.close()
+
         if user:
             return True
         else:
@@ -351,8 +372,10 @@ class UserHandler():
                 (User.username == username) & (User.study_name == self.study_name)).update({User.token: auth_token,
                                                                                         User.token_issued: auth_token_issued_time,
                                                                                         User.token_expiry: auth_token_expiry_time})
+            self.session.commit()
             return True
         except:
+            self.session.rollback()
             return False
 
     def gen_random_pass(self, string_type: str, size: int = 8) -> str:
